from pydantic import BaseModel, Field
from typing import List, Optional

class ProductReviewInput(BaseModel):
    """Input model for product review processing"""
    product_id: str = Field(..., description="Unique identifier for the product")
    features: List[str] = Field(..., description="Features to analyze")
    new_review: Optional[str] = Field(default=None, description="Optional new review to add")
    is_rating_evaluation_required: bool = Field(
        default=True, 
        description="Flag to determine if rating evaluation is needed"
    )

    class Config:
        """Pydantic model configuration"""
        json_schema_extra = {
            "example": {
                # "product_id": "iPhone 15 Pro Max",
                "product_id": "",
                "features": ["camera", "battery", "display", "design"],
                # "new_review": "Great phone with excellent battery life!",
                "new_review": "",
                "is_rating_evaluation_required": True
            }
        }