from fastapi import FastAPI
from reviewsense.api.routes import router
from reviewsense.core.config import get_settings
from fastapi.middleware.cors import CORSMiddleware

def create_app() -> FastAPI:
    """
    Create and configure the FastAPI application
    
    Returns:
        FastAPI: Configured application instance
    """
    app = FastAPI(
        title="ReviewSense",
        description="AI-powered Product Review Analysis Platform"
    )
    
    # Include routes
    app.include_router(router)
    
    return app

app = create_app()

app.add_middleware(
    CORSMiddleware,
    allow_origins=["http://localhost:3000"],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

if __name__ == '__main__':
    import uvicorn
    uvicorn.run(app, host='0.0.0.0', port=8007)
