# services/review_service.py

from typing import List, Dict, Optional
from reviewsense.services.review_fetcher import ReviewFetcher
from reviewsense.services.review_rater import ReviewRater
from reviewsense.services.review_adder import ReviewAdder

class ReviewService:
    """Service class for handling product reviews"""

    def __init__(self, collection_name: str = "android_phone_reviews", embedding_model: str = "sentence-transformers/all-mpnet-base-v2"):
        """
        Initialize the review service with vector database and embeddings
        """
        self.fetcher = ReviewFetcher()
        self.rater = ReviewRater()
        self.adder = ReviewAdder()

    def fetch_reviews(self, product_id: str, features: List[str], threshold: float = 0.6) -> Dict[str, List[str]]:
        return self.fetcher.fetch_reviews(product_id, features, threshold)

    def generate_feature_ratings(self, reviews_by_feature: Dict[str, List[str]]) -> Dict[str, Optional[float]]:
        return self.rater.generate_feature_ratings(reviews_by_feature)

    def add_review(self, product_id: str, review: str) -> str:
        return self.adder.add_review(product_id, review)
