# src/reviewsense/core/database.py
from functools import lru_cache

from langchain_community.embeddings import HuggingFaceInferenceAPIEmbeddings
from langchain_huggingface import HuggingFaceEmbeddings
from langchain_astradb import AstraDBVectorStore
from reviewsense.core.config import get_settings

@lru_cache(maxsize=1)
def get_vector_store(
    collection_name: str = "One",
    embedding_model: str = "sentence-transformers/all-mpnet-base-v2"
):
    """
    Create a singleton vector store instance
    
    Args:
        collection_name (str): Database collection name
        embedding_model (str): Embedding model to use
    
    Returns:
        AstraDBVectorStore: Configured vector store instance
    """
    settings = get_settings()
    
    # Initialize embeddings
    embeddings = HuggingFaceInferenceAPIEmbeddings(api_key="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", model_name="BAAI/bge-base-en-v1.5")
    
    # Create and return vector store
    return AstraDBVectorStore(
        collection_name=collection_name,
        embedding=embeddings,
        api_endpoint="https://9706ee0b-b3e8-4ee2-bb26-45e8a0db1586-us-east-2.apps.astra.datastax.com",
        token="AstraCS:OEbpcggZbUjOvRiesULZkTnf:9d215d8d32c2ffb09081212208e474f81a0bcdde45e7b683cd67f4a1a936a8bf",
        namespace="default_keyspace",
    )